@@ -1,7 +1,7 @@
 package HTTP::Tiny::Patch::Cache;
 
-our $DATE = '2018-09-20'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2018-10-06'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -36,10 +36,13 @@ my $p_request = sub {
     }
     my $cachepath = "$cachedir/".Digest::SHA::sha256_hex($url);
     log_trace "Cache file is %s", $cachepath;
-    my $maxage = $ENV{CACHE_MAX_AGE} // 86400;
+    my $maxage = $config{-max_age} //
+        $ENV{HTTP_TINY_CACHE_MAX_AGE} //
+        $ENV{CACHE_MAX_AGE} // 86400;
     if (!(-f $cachepath) || (-M _) > $maxage/86400) {
         log_trace "Retrieving response from remote ...";
         my $res = $orig->(@_);
+        return $res unless $res->{status} =~ /\A[23]/; # HTTP::Tiny only regards 2xx as success
         log_trace "Saving response to cache ...";
         open my $fh, ">", $cachepath or die "Can't create cache file '$cachepath' for '$url': $!";
         print $fh JSON::MaybeXS::encode_json($res);
@@ -59,10 +62,9 @@ sub patch_data {
     return {
         v => 3,
         config => {
-            #-max_age => {
-            #    schema  => 'posint*',
-            #    default => 86400,
-            #},
+            -max_age => {
+                schema  => 'posint*',
+            },
         },
         patches => [
             {
@@ -90,13 +92,15 @@ HTTP::Tiny::Patch::Cache - Cache HTTP::Tiny responses
 
 =head1 VERSION
 
-This document describes version 0.002 of HTTP::Tiny::Patch::Cache (from Perl distribution HTTP-Tiny-Patch-Cache), released on 2018-09-20.
+This document describes version 0.003 of HTTP::Tiny::Patch::Cache (from Perl distribution HTTP-Tiny-Patch-Cache), released on 2018-10-06.
 
 =head1 SYNOPSIS
 
 From Perl:
 
- use HTTP::Tiny::Patch::Cache;
+ use HTTP::Tiny::Patch::Cache
+     # -max_age => 7200, # optional, sets max age, can also be set via environment variables
+ ;
 
  my $res  = HTTP::Tiny->new->get("http://www.example.com/");
  my $res2 = HTTP::Tiny->request(GET => "http://www.example.com/"); # cached response
@@ -129,13 +133,23 @@ saving bandwidth when repeatedly getting huge HTTP pages).
 
 =head1 CONFIGURATION
 
+=head2 -max_age
+
+Int. Sets maximum age for cache. If not set, will consult environment variables
+(see L</"ENVIRONMENT">). If all environment variables are not set, will use the
+default 86400.
+
 =head1 FAQ
 
 =head1 ENVIRONMENT
 
 =head2 CACHE_MAX_AGE
 
-Int. Default 86400. Set period of cache.
+Int. Will be consulted after L</"HTTP_TINY_PATCH_CACHE_MAX_AGE">.
+
+=head2 HTTP_TINY_PATCH_CACHE_MAX_AGE
+
+Int. Will be consulted before L</"CACHE_MAX_AGE">.
 
 =head1 HOMEPAGE
 
